/*
 Tecnisa - Tecnologia em Informtica

 Nome: CONSULTA_ERRO_FISCAL

  Descrio:
  Funo para verificar erros na regra fiscal.

 Criao:
 11/06/2012 - Marcelo Alexsandro Souza Silva
*/

IF EXISTS (SELECT * FROM SYSOBJECTS O, SYSUSERS U
           WHERE O.NAME = 'CONSULTA_ERRO_REGRAFISCAL'
             AND TYPE = 'TF'
             AND U.UID = O.UID
             AND U.NAME = USER)
DROP FUNCTION CONSULTA_ERRO_REGRAFISCAL
GO

CREATE FUNCTION CONSULTA_ERRO_REGRAFISCAL
(@P_CDREGRAFISC VARCHAR(10))
returns @ERRO_REGRAFISCAL_TABLE table
(
CDREGRAFISC      VARCHAR(10),
CDIMPOSTO        VARCHAR(2),
CDIMPOSTONFE     VARCHAR(2),
CDSITUTRIB       VARCHAR(2),
CDFISCAL         VARCHAR(1),
VRALIQUOTA       DOUBLE PRECISION,
CDFISCOPER       VARCHAR(10),
IDCADPADRAO      VARCHAR(1),
IDERRO           INTEGER
)
AS
BEGIN
   DECLARE @V_DTVALREGRAFISC  DATETIME;

   SELECT
      @V_DTVALREGRAFISC = MAX(DTVALREGRAFISC)
     FROM REGRAFISCAL
    WHERE CDREGRAFISC = @P_CDREGRAFISC;

   DECLARE @V_COUNT INTEGER;
   DECLARE @V_IMPOSTO_OBRIGATORIO_CDIMPOSTO    VARCHAR(2);
   DECLARE @V_IMPOSTO_OBRIGATORIO_CDIMPOSTONFE VARCHAR(2);
   DECLARE @V_IMPOSTO_RANGE                    VARCHAR(2);
   
   SET @V_COUNT = 0;
   SELECT @V_COUNT = COUNT(1)
     FROM VINCULOFISREGRA
    WHERE VINCULOFISREGRA.CDREGRAFISC = @P_CDREGRAFISC;
   IF @V_COUNT = 0 BEGIN
      INSERT INTO @ERRO_REGRAFISCAL_TABLE(CDREGRAFISC, IDERRO)
      VALUES (@P_CDREGRAFISC, 0) /*Nao ha vinculo algum para a respectiva regra fiscal*/
   END;

   DECLARE C_IMPOSTO_OBRIGATORIO CURSOR FOR
      SELECT IMPREGRAFISCAL.CDIMPOSTO, IMPOSTO.CDIMPOSTONFE
         FROM IMPREGRAFISCAL, IMPOSTO
        WHERE IMPREGRAFISCAL.CDREGRAFISC = @P_CDREGRAFISC
          AND IMPREGRAFISCAL.CDIMPOSTO   = IMPOSTO.CDIMPOSTO
          AND IMPREGRAFISCAL.IDIMPOBRIGREGRA = 'S'
          AND NOT EXISTS (SELECT 1
                            FROM DADOSFISCREGRA
                           WHERE DADOSFISCREGRA.CDREGRAFISC = @P_CDREGRAFISC
                             AND DADOSFISCREGRA.CDIMPOSTO = IMPREGRAFISCAL.CDIMPOSTO)
          AND NOT EXISTS (SELECT 1
                            FROM DADOSFISCPROD
                           WHERE DADOSFISCPROD.CDREGRAFISC = @P_CDREGRAFISC
                             AND DADOSFISCPROD.CDIMPOSTO = IMPREGRAFISCAL.CDIMPOSTO)
          AND NOT EXISTS (SELECT 1
                            FROM DADOSFISCNCM
                           WHERE DADOSFISCNCM.CDREGRAFISC = @P_CDREGRAFISC
                             AND DADOSFISCNCM.CDIMPOSTO = IMPREGRAFISCAL.CDIMPOSTO)
       ORDER BY IMPREGRAFISCAL.CDIMPOSTO;
   OPEN C_IMPOSTO_OBRIGATORIO;
   FETCH NEXT FROM C_IMPOSTO_OBRIGATORIO INTO @V_IMPOSTO_OBRIGATORIO_CDIMPOSTO,
                                              @V_IMPOSTO_OBRIGATORIO_CDIMPOSTONFE;
   WHILE (@@FETCH_STATUS = 0)
   BEGIN
      INSERT INTO @ERRO_REGRAFISCAL_TABLE(CDREGRAFISC, CDIMPOSTO, CDIMPOSTONFE, IDERRO)
      VALUES (@P_CDREGRAFISC, @V_IMPOSTO_OBRIGATORIO_CDIMPOSTO, @V_IMPOSTO_OBRIGATORIO_CDIMPOSTONFE, 1) /*Imposto Obrigatorio sem dados fiscais*/
      FETCH NEXT FROM C_IMPOSTO_OBRIGATORIO INTO @V_IMPOSTO_OBRIGATORIO_CDIMPOSTO,
                                                 @V_IMPOSTO_OBRIGATORIO_CDIMPOSTONFE;
   END;
   CLOSE C_IMPOSTO_OBRIGATORIO;
   DEALLOCATE C_IMPOSTO_OBRIGATORIO;


   DECLARE @V_CFOP_OBRIGATORIO_CDIMPOSTO    VARCHAR(2);
   DECLARE @V_CFOP_OBRIGATORIO_CDIMPOSTONFE VARCHAR(2);
   DECLARE @V_CFOP_OBRIGATORIO_NMIMPOSTO    VARCHAR(30);

   DECLARE C_CFOP_OBRIGATORIO CURSOR FOR
      SELECT IMPOSTO.CDIMPOSTO, IMPOSTO.NMIMPOSTO, IMPOSTO.CDIMPOSTONFE
         FROM IMPREGRAFISCAL, IMPOSTO
        WHERE IMPREGRAFISCAL.CDREGRAFISC = @P_CDREGRAFISC
          AND IMPREGRAFISCAL.CDIMPOSTO = IMPOSTO.CDIMPOSTO
          AND IMPREGRAFISCAL.IDIMPOBRIGREGRA = 'S'
          AND IMPOSTO.IDUTCFOPREGFISC = 'S'
          AND NOT EXISTS (SELECT 1
                            FROM CFOPNCMREGRAFIS
                           WHERE CFOPNCMREGRAFIS.CDREGRAFISC = @P_CDREGRAFISC)
          AND NOT EXISTS (SELECT 1
                            FROM CFOPADRAOREGFIS
                           WHERE CFOPADRAOREGFIS.CDREGRAFISC = @P_CDREGRAFISC)
          AND NOT EXISTS (SELECT 1
                            FROM CFOPREGRAFISCAL
                           WHERE CFOPREGRAFISCAL.CDREGRAFISC = @P_CDREGRAFISC)
      ORDER BY IMPOSTO.CDIMPOSTO;
   OPEN C_CFOP_OBRIGATORIO;
   FETCH NEXT FROM C_CFOP_OBRIGATORIO INTO @V_CFOP_OBRIGATORIO_CDIMPOSTO,
                                           @V_CFOP_OBRIGATORIO_CDIMPOSTONFE,
                                           @V_CFOP_OBRIGATORIO_NMIMPOSTO;
   WHILE (@@FETCH_STATUS = 0)
   BEGIN
      INSERT INTO @ERRO_REGRAFISCAL_TABLE(CDREGRAFISC, CDIMPOSTO, CDIMPOSTONFE, IDERRO)
      VALUES (@P_CDREGRAFISC, @V_CFOP_OBRIGATORIO_CDIMPOSTO, @V_CFOP_OBRIGATORIO_CDIMPOSTONFE, 2) /*Imposto exige CFOP e a regra nao possui parametrizacao de CFOP*/
      FETCH NEXT FROM C_CFOP_OBRIGATORIO INTO @V_CFOP_OBRIGATORIO_CDIMPOSTO,
                                              @V_CFOP_OBRIGATORIO_CDIMPOSTONFE,
                                              @V_CFOP_OBRIGATORIO_NMIMPOSTO;

   END;
   CLOSE C_CFOP_OBRIGATORIO;
   DEALLOCATE C_CFOP_OBRIGATORIO;

   DECLARE @V_CST_OBRIGATORIO_CDIMPOSTO    VARCHAR(2);
   DECLARE @V_CST_OBRIGATORIO_CDIMPOSTONFE VARCHAR(2);
   DECLARE @V_CST_OBRIGATORIO_NMIMPOSTO    VARCHAR(30);

   DECLARE C_CST_OBRIGATORIO CURSOR FOR
      SELECT IMPOSTO.CDIMPOSTO, IMPOSTO.NMIMPOSTO, IMPOSTO.CDIMPOSTONFE
         FROM IMPREGRAFISCAL, IMPOSTO
        WHERE IMPREGRAFISCAL.CDREGRAFISC = @P_CDREGRAFISC
          AND IMPREGRAFISCAL.CDIMPOSTO = IMPOSTO.CDIMPOSTO
          AND IMPREGRAFISCAL.IDIMPOBRIGREGRA = 'S'
          AND IMPOSTO.IDUTCSTREGFISC = 'S'
          AND (EXISTS (SELECT 1
                         FROM DADOSFISCREGRA
                        WHERE DADOSFISCREGRA.CDREGRAFISC = @P_CDREGRAFISC
                          AND DADOSFISCREGRA.CDIMPOSTO = IMPREGRAFISCAL.CDIMPOSTO
                          AND DADOSFISCREGRA.CDSITUTRIB IS NULL) OR
               EXISTS (SELECT 1
                        FROM DADOSFISCPROD
                       WHERE DADOSFISCPROD.CDREGRAFISC = @P_CDREGRAFISC
                         AND DADOSFISCPROD.CDIMPOSTO = IMPREGRAFISCAL.CDIMPOSTO
                         AND DADOSFISCPROD.CDSITUTRIB IS NULL)   OR
               EXISTS (SELECT 1
                        FROM DADOSFISCNCM
                       WHERE DADOSFISCNCM.CDREGRAFISC = @P_CDREGRAFISC
                         AND DADOSFISCNCM.CDIMPOSTO = IMPREGRAFISCAL.CDIMPOSTO
                         AND DADOSFISCNCM.CDSITUTRIB IS NULL))
       ORDER BY IMPOSTO.CDIMPOSTO;
   OPEN C_CST_OBRIGATORIO;
   FETCH NEXT FROM C_CST_OBRIGATORIO INTO @V_CST_OBRIGATORIO_CDIMPOSTO,
                                          @V_CST_OBRIGATORIO_CDIMPOSTONFE,
                                          @V_CST_OBRIGATORIO_NMIMPOSTO;
   WHILE (@@FETCH_STATUS = 0)
   BEGIN
      INSERT INTO @ERRO_REGRAFISCAL_TABLE(CDREGRAFISC, CDIMPOSTO, CDIMPOSTONFE, IDERRO)
      VALUES (@P_CDREGRAFISC, @V_CST_OBRIGATORIO_CDIMPOSTO, @V_CST_OBRIGATORIO_CDIMPOSTONFE, 3) /*Imposto exige CST e existem dados fiscais (padrao e/ou por produto) sem CST*/
      FETCH NEXT FROM C_CST_OBRIGATORIO INTO @V_CST_OBRIGATORIO_CDIMPOSTO,
                                             @V_CST_OBRIGATORIO_CDIMPOSTONFE,
                                             @V_CST_OBRIGATORIO_NMIMPOSTO;
   END;
   CLOSE C_CST_OBRIGATORIO;
   DEALLOCATE C_CST_OBRIGATORIO;

   DECLARE @V_DADOSFISCREGRA_CDIMPOSTONFE    VARCHAR(2);
   DECLARE @V_DADOSFISCREGRA_CDIMPOSTO       VARCHAR(2);
   DECLARE @V_DADOSFISCREGRA_CDSITUTRIB      VARCHAR(2);
   DECLARE @V_DADOSFISCREGRA_CDFISCAL        VARCHAR(1);
   DECLARE @V_DADOSFISCREGRA_IDUTVLRQTDEIMPO VARCHAR(1);
   DECLARE @V_DADOSFISCREGRA_CDNATUBCPCSTNFE VARCHAR(2);
   DECLARE @V_DADOSFISCREGRA_CDTPCRPICOSTNFE VARCHAR(3);
   DECLARE @V_DADOSFISCREGRA_CDNATUREC       VARCHAR(5);
   DECLARE @V_DADOSFISCREGRA_VRALIQUOTA      DOUBLE PRECISION;

   DECLARE C_DADOSFISCREGRA CURSOR FOR
      SELECT IMPOSTO.CDIMPOSTONFE, IMPOSTO.CDIMPOSTO, DADOSFISCREGRA.CDSITUTRIB, DADOSFISCREGRA.CDFISCAL, IMPOSTO.IDUTVLRQTDEIMPO,
              DADOSFISCREGRA.CDNATUBCPCSTNFE, DADOSFISCREGRA.CDTPCRPICOSTNFE, DADOSFISCREGRA.VRALIQUOTA, DADOSFISCREGRA.CDNATUREC
        FROM DADOSFISCREGRA, IMPOSTO
       WHERE DADOSFISCREGRA.CDREGRAFISC = @P_CDREGRAFISC
         AND DADOSFISCREGRA.CDIMPOSTO = IMPOSTO.CDIMPOSTO;
   OPEN C_DADOSFISCREGRA;
   FETCH NEXT FROM C_DADOSFISCREGRA INTO @V_DADOSFISCREGRA_CDIMPOSTONFE,
                                         @V_DADOSFISCREGRA_CDIMPOSTO,
                                         @V_DADOSFISCREGRA_CDSITUTRIB,
                                         @V_DADOSFISCREGRA_CDFISCAL,
                                         @V_DADOSFISCREGRA_IDUTVLRQTDEIMPO,
                                         @V_DADOSFISCREGRA_CDNATUBCPCSTNFE,
                                         @V_DADOSFISCREGRA_CDTPCRPICOSTNFE,
                                         @V_DADOSFISCREGRA_VRALIQUOTA,
                                         @V_DADOSFISCREGRA_CDNATUREC;
   WHILE (@@FETCH_STATUS = 0)
   BEGIN
      IF @V_DADOSFISCREGRA_CDSITUTRIB IS NOT NULL BEGIN
         IF @V_DADOSFISCREGRA_CDIMPOSTONFE IS NOT NULL BEGIN
            SET @V_COUNT = 0;
            SELECT @V_COUNT = COUNT(1)
              FROM PARAMCST
             WHERE CDIMPOSTO  = @V_DADOSFISCREGRA_CDIMPOSTONFE
               AND CDSITUTRIB = @V_DADOSFISCREGRA_CDSITUTRIB;
            IF @V_COUNT = 0 BEGIN
               INSERT INTO @ERRO_REGRAFISCAL_TABLE(CDREGRAFISC, CDIMPOSTO, CDIMPOSTONFE, CDSITUTRIB, IDCADPADRAO, IDERRO)
               VALUES (@P_CDREGRAFISC, @V_DADOSFISCREGRA_CDIMPOSTO, @V_DADOSFISCREGRA_CDIMPOSTONFE, @V_DADOSFISCREGRA_CDSITUTRIB, 'S', 4) /*CST no cadastrado para o imposto.*/
            END;

            SET @V_COUNT = 0;
            SELECT @V_COUNT = COUNT(1)
              FROM PARAMCST
             WHERE CDIMPOSTO  = @V_DADOSFISCREGRA_CDIMPOSTONFE
               AND CDSITUTRIB = @V_DADOSFISCREGRA_CDSITUTRIB
               AND ((IDUTICDFISCAL1 = 'S' AND @V_DADOSFISCREGRA_CDFISCAL = '1') OR
                    (IDUTICDFISCAL2 = 'S' AND @V_DADOSFISCREGRA_CDFISCAL = '2') OR
                    (IDUTICDFISCAL3 = 'S' AND @V_DADOSFISCREGRA_CDFISCAL = '3'));
            IF @V_COUNT = 0 BEGIN
               INSERT INTO @ERRO_REGRAFISCAL_TABLE(CDREGRAFISC, CDIMPOSTO, CDIMPOSTONFE, CDSITUTRIB, CDFISCAL, IDCADPADRAO, IDERRO)
               VALUES (@P_CDREGRAFISC, @V_DADOSFISCREGRA_CDIMPOSTO, @V_DADOSFISCREGRA_CDIMPOSTONFE, @V_DADOSFISCREGRA_CDSITUTRIB, @V_DADOSFISCREGRA_CDFISCAL, 'S', 5) /*Cdigo Fiscal invlido para o respectivo CST e imposto*/
            END;

            IF @V_DADOSFISCREGRA_IDUTVLRQTDEIMPO = 'S' BEGIN
               SET @V_COUNT = 0;
               SELECT @V_COUNT = COUNT(1)
                 FROM PARAMCST
                WHERE CDIMPOSTO      = @V_DADOSFISCREGRA_CDIMPOSTONFE
                  AND CDSITUTRIB     = @V_DADOSFISCREGRA_CDSITUTRIB;
               IF @V_COUNT = 0 BEGIN
                  INSERT INTO @ERRO_REGRAFISCAL_TABLE(CDREGRAFISC, CDIMPOSTO, CDIMPOSTONFE, CDSITUTRIB, IDCADPADRAO, IDERRO)
                  VALUES (@P_CDREGRAFISC, @V_DADOSFISCREGRA_CDIMPOSTO, @V_DADOSFISCREGRA_CDIMPOSTONFE, @V_DADOSFISCREGRA_CDSITUTRIB, 'S', 6) /*CST invlido para imposto cujo valor de alquota  definido por quantidade.*/
               END;
            END;

            IF @V_DADOSFISCREGRA_CDNATUBCPCSTNFE IS NULL OR
               @V_DADOSFISCREGRA_CDTPCRPICOSTNFE IS NULL BEGIN
               SET @V_COUNT = 0;
               SELECT @V_COUNT = COUNT(1)
                 FROM PARAMCST
                WHERE CDIMPOSTO       = @V_DADOSFISCREGRA_CDIMPOSTONFE
                  AND CDSITUTRIB      = @V_DADOSFISCREGRA_CDSITUTRIB
                  AND IDUTITIPCREDITO = 'N';
               IF @V_COUNT = 0 BEGIN
                  INSERT INTO @ERRO_REGRAFISCAL_TABLE(CDREGRAFISC, CDIMPOSTO, CDIMPOSTONFE, CDSITUTRIB, IDCADPADRAO, IDERRO)
                  VALUES (@P_CDREGRAFISC, @V_DADOSFISCREGRA_CDIMPOSTO, @V_DADOSFISCREGRA_CDIMPOSTONFE, @V_DADOSFISCREGRA_CDSITUTRIB, 'S', 7) /*Tipo de Credito e natureza da base de clculo obrigatorios para o respectivo imposto e CST*/
               END;
            END;

         END;
      END;

      IF (@V_DADOSFISCREGRA_CDIMPOSTONFE = '50') OR (@V_DADOSFISCREGRA_CDIMPOSTONFE = '60') BEGIN
         IF (@V_DADOSFISCREGRA_CDSITUTRIB <> '05') AND (@V_DADOSFISCREGRA_CDSITUTRIB <> '49') AND (@V_DADOSFISCREGRA_CDSITUTRIB <> '99') BEGIN
            SET @V_COUNT = 0;
            SELECT @V_COUNT = COUNT(1)
              FROM ALIQUOTACSTNFE
             WHERE CDIMPOSTO = @V_DADOSFISCREGRA_CDIMPOSTONFE
               AND CDSITUTRIBNFE = @V_DADOSFISCREGRA_CDSITUTRIB
               AND VRALIQUOTA = CASE @V_DADOSFISCREGRA_CDFISCAL WHEN '1' THEN @V_DADOSFISCREGRA_VRALIQUOTA ELSE 0 END;
            IF @V_COUNT = 0 BEGIN
               INSERT INTO @ERRO_REGRAFISCAL_TABLE(CDREGRAFISC, CDIMPOSTO, CDIMPOSTONFE, CDSITUTRIB, IDCADPADRAO, IDERRO)
               VALUES (@P_CDREGRAFISC, @V_DADOSFISCREGRA_CDIMPOSTO, @V_DADOSFISCREGRA_CDIMPOSTONFE, @V_DADOSFISCREGRA_CDSITUTRIB, 'S', 8) /*Valor de aliquota invalida para o respectivo imposto e CST*/
            END;
         END;
      END;
      FETCH NEXT FROM C_DADOSFISCREGRA INTO @V_DADOSFISCREGRA_CDIMPOSTONFE,
                                            @V_DADOSFISCREGRA_CDIMPOSTO,
                                            @V_DADOSFISCREGRA_CDSITUTRIB,
                                            @V_DADOSFISCREGRA_CDFISCAL,
                                            @V_DADOSFISCREGRA_IDUTVLRQTDEIMPO,
                                            @V_DADOSFISCREGRA_CDNATUBCPCSTNFE,
                                            @V_DADOSFISCREGRA_CDTPCRPICOSTNFE,
                                            @V_DADOSFISCREGRA_VRALIQUOTA,
                                            @V_DADOSFISCREGRA_CDNATUREC;
   END;
   CLOSE C_DADOSFISCREGRA;
   DEALLOCATE C_DADOSFISCREGRA;


   DECLARE @V_DADOSFISCPROD_CDIMPOSTONFE    VARCHAR(2);
   DECLARE @V_DADOSFISCPROD_CDIMPOSTO       VARCHAR(2);
   DECLARE @V_DADOSFISCPROD_CDSITUTRIB      VARCHAR(2);
   DECLARE @V_DADOSFISCPROD_CDFISCAL        VARCHAR(1);
   DECLARE @V_DADOSFISCPROD_IDUTVLRQTDEIMPO VARCHAR(1);
   DECLARE @V_DADOSFISCPROD_CDNATUBCPCSTNFE VARCHAR(2);
   DECLARE @V_DADOSFISCPROD_CDTPCRPICOSTNFE VARCHAR(3);
   DECLARE @V_DADOSFISCPROD_CDNATUREC       VARCHAR(5);
   DECLARE @V_DADOSFISCPROD_VRALIQUOTA      DOUBLE PRECISION;

   DECLARE C_DADOSFISCPROD CURSOR FOR
      SELECT IMPOSTO.CDIMPOSTONFE, IMPOSTO.CDIMPOSTO, DADOSFISCPROD.CDSITUTRIB, DADOSFISCPROD.CDFISCAL, IMPOSTO.IDUTVLRQTDEIMPO,
              DADOSFISCPROD.CDNATUBCPCSTNFE, DADOSFISCPROD.CDTPCRPICOSTNFE, DADOSFISCPROD.VRALIQUOTA, DADOSFISCPROD.CDNATUREC
        FROM DADOSFISCPROD, IMPOSTO
       WHERE DADOSFISCPROD.CDREGRAFISC = @P_CDREGRAFISC
         AND DADOSFISCPROD.CDIMPOSTO = IMPOSTO.CDIMPOSTO;
   OPEN C_DADOSFISCPROD;
   FETCH NEXT FROM C_DADOSFISCPROD INTO @V_DADOSFISCPROD_CDIMPOSTONFE,
                                        @V_DADOSFISCPROD_CDIMPOSTO,
                                        @V_DADOSFISCPROD_CDSITUTRIB,
                                        @V_DADOSFISCPROD_CDFISCAL,
                                        @V_DADOSFISCPROD_IDUTVLRQTDEIMPO,
                                        @V_DADOSFISCPROD_CDNATUBCPCSTNFE,
                                        @V_DADOSFISCPROD_CDTPCRPICOSTNFE,
                                        @V_DADOSFISCPROD_VRALIQUOTA,
                                        @V_DADOSFISCPROD_CDNATUREC;
   WHILE (@@FETCH_STATUS = 0)
   BEGIN
      IF @V_DADOSFISCPROD_CDSITUTRIB IS NOT NULL BEGIN
         IF @V_DADOSFISCPROD_CDIMPOSTONFE IS NOT NULL BEGIN
            SET @V_COUNT = 0;
            SELECT @V_COUNT = COUNT(1)
              FROM PARAMCST
             WHERE CDIMPOSTO  = @V_DADOSFISCPROD_CDIMPOSTONFE
               AND CDSITUTRIB = @V_DADOSFISCPROD_CDSITUTRIB;
            IF @V_COUNT = 0 BEGIN
               INSERT INTO @ERRO_REGRAFISCAL_TABLE(CDREGRAFISC, CDIMPOSTO, CDIMPOSTONFE, CDSITUTRIB, IDCADPADRAO, IDERRO)
               VALUES (@P_CDREGRAFISC, @V_DADOSFISCPROD_CDIMPOSTO, @V_DADOSFISCPROD_CDIMPOSTONFE, @V_DADOSFISCPROD_CDSITUTRIB, 'N', 4) /*CST no cadastrado para o imposto.*/
            END;

            SET @V_COUNT = 0;
            SELECT @V_COUNT = COUNT(1)
              FROM PARAMCST
             WHERE CDIMPOSTO  = @V_DADOSFISCPROD_CDIMPOSTONFE
               AND CDSITUTRIB = @V_DADOSFISCPROD_CDSITUTRIB
               AND ((IDUTICDFISCAL1 = 'S' AND @V_DADOSFISCPROD_CDFISCAL = '1') OR
                    (IDUTICDFISCAL2 = 'S' AND @V_DADOSFISCPROD_CDFISCAL = '2') OR
                    (IDUTICDFISCAL3 = 'S' AND @V_DADOSFISCPROD_CDFISCAL = '3'));
            IF @V_COUNT = 0 BEGIN
               INSERT INTO @ERRO_REGRAFISCAL_TABLE(CDREGRAFISC, CDIMPOSTO, CDIMPOSTONFE, CDSITUTRIB, CDFISCAL, IDCADPADRAO, IDERRO)
               VALUES (@P_CDREGRAFISC, @V_DADOSFISCPROD_CDIMPOSTO, @V_DADOSFISCPROD_CDIMPOSTONFE, @V_DADOSFISCPROD_CDSITUTRIB, @V_DADOSFISCPROD_CDFISCAL, 'N', 5) /*Cdigo Fiscal invlido para o respectivo CST e imposto*/
            END;

            IF @V_DADOSFISCPROD_IDUTVLRQTDEIMPO = 'S' BEGIN
               SET @V_COUNT = 0;
               SELECT @V_COUNT = COUNT(1)
                 FROM PARAMCST
                WHERE CDIMPOSTO      = @V_DADOSFISCPROD_CDIMPOSTONFE
                  AND CDSITUTRIB     = @V_DADOSFISCPROD_CDSITUTRIB;
               IF @V_COUNT = 0 BEGIN
                  INSERT INTO @ERRO_REGRAFISCAL_TABLE(CDREGRAFISC, CDIMPOSTO, CDIMPOSTONFE, CDSITUTRIB, IDCADPADRAO, IDERRO)
                  VALUES (@P_CDREGRAFISC, @V_DADOSFISCPROD_CDIMPOSTO, @V_DADOSFISCPROD_CDIMPOSTONFE, @V_DADOSFISCPROD_CDSITUTRIB, 'N', 6) /*CST invlido para imposto cujo valor de alquota  definido por quantidade.*/
               END;
            END;

            IF @V_DADOSFISCPROD_CDNATUBCPCSTNFE IS NULL OR
               @V_DADOSFISCPROD_CDTPCRPICOSTNFE IS NULL BEGIN
               SET @V_COUNT = 0;
               SELECT @V_COUNT = COUNT(1)
                 FROM PARAMCST
                WHERE CDIMPOSTO       = @V_DADOSFISCPROD_CDIMPOSTONFE
                  AND CDSITUTRIB      = @V_DADOSFISCPROD_CDSITUTRIB
                  AND IDUTITIPCREDITO = 'N';
               IF @V_COUNT = 0 BEGIN
                  INSERT INTO @ERRO_REGRAFISCAL_TABLE(CDREGRAFISC, CDIMPOSTO, CDIMPOSTONFE, CDSITUTRIB, IDCADPADRAO, IDERRO)
                  VALUES (@P_CDREGRAFISC, @V_DADOSFISCPROD_CDIMPOSTO, @V_DADOSFISCPROD_CDIMPOSTONFE, @V_DADOSFISCPROD_CDSITUTRIB, 'N', 7) /*Tipo de Credito e natureza da base de clculo obrigatorios para o respectivo imposto e CST*/
               END;
            END;


         END;
      END;

      IF (@V_DADOSFISCPROD_CDIMPOSTONFE = '50') OR (@V_DADOSFISCPROD_CDIMPOSTONFE = '60') BEGIN
         IF (@V_DADOSFISCPROD_CDSITUTRIB <> '05') AND (@V_DADOSFISCPROD_CDSITUTRIB <> '49') AND (@V_DADOSFISCPROD_CDSITUTRIB <> '99') BEGIN
            SET @V_COUNT = 0;
            SELECT @V_COUNT = COUNT(1)
              FROM ALIQUOTACSTNFE
             WHERE CDIMPOSTO = @V_DADOSFISCPROD_CDIMPOSTONFE
               AND CDSITUTRIBNFE = @V_DADOSFISCPROD_CDSITUTRIB
               AND VRALIQUOTA = CASE @V_DADOSFISCPROD_CDFISCAL WHEN '1' THEN @V_DADOSFISCPROD_VRALIQUOTA ELSE 0 END;
            IF @V_COUNT = 0 BEGIN
               INSERT INTO @ERRO_REGRAFISCAL_TABLE(CDREGRAFISC, CDIMPOSTO, CDIMPOSTONFE, CDSITUTRIB, IDCADPADRAO, IDERRO)
               VALUES (@P_CDREGRAFISC, @V_DADOSFISCPROD_CDIMPOSTO, @V_DADOSFISCPROD_CDIMPOSTONFE, @V_DADOSFISCPROD_CDSITUTRIB, 'N', 8) /*Valor de aliquota invalida para o respectivo imposto e CST*/
            END;
         END;
      END;
      FETCH NEXT FROM C_DADOSFISCPROD INTO @V_DADOSFISCPROD_CDIMPOSTONFE,
                                           @V_DADOSFISCPROD_CDIMPOSTO,
                                           @V_DADOSFISCPROD_CDSITUTRIB,
                                           @V_DADOSFISCPROD_CDFISCAL,
                                           @V_DADOSFISCPROD_IDUTVLRQTDEIMPO,
                                           @V_DADOSFISCPROD_CDNATUBCPCSTNFE,
                                           @V_DADOSFISCPROD_CDTPCRPICOSTNFE,
                                           @V_DADOSFISCPROD_VRALIQUOTA,
                                           @V_DADOSFISCPROD_CDNATUREC;

   END;
   CLOSE C_DADOSFISCPROD;
   DEALLOCATE C_DADOSFISCPROD;

   DECLARE @V_DADOSFISCNCM_CDIMPOSTONFE    VARCHAR(2);
   DECLARE @V_DADOSFISCNCM_CDIMPOSTO       VARCHAR(2);
   DECLARE @V_DADOSFISCNCM_CDSITUTRIB      VARCHAR(2);
   DECLARE @V_DADOSFISCNCM_CDFISCAL        VARCHAR(1);
   DECLARE @V_DADOSFISCNCM_IDUTVLRQTDEIMPO VARCHAR(1);
   DECLARE @V_DADOSFISCNCM_CDNATUBCPCSTNFE VARCHAR(2);
   DECLARE @V_DADOSFISCNCM_CDTPCRPICOSTNFE VARCHAR(3);
   DECLARE @V_DADOSFISCNCM_CDNATUREC       VARCHAR(5);
   DECLARE @V_DADOSFISCNCM_VRALIQUOTA      DOUBLE PRECISION;

   DECLARE C_DADOSFISCNCM CURSOR FOR
      SELECT IMPOSTO.CDIMPOSTONFE, IMPOSTO.CDIMPOSTO, DADOSFISCNCM.CDSITUTRIB, DADOSFISCNCM.CDFISCAL, IMPOSTO.IDUTVLRQTDEIMPO,
              DADOSFISCNCM.CDNATUBCPCSTNFE, DADOSFISCNCM.CDTPCRPICOSTNFE, DADOSFISCNCM.VRALIQUOTA, DADOSFISCNCM.CDNATUREC
        FROM DADOSFISCNCM, IMPOSTO
       WHERE DADOSFISCNCM.CDREGRAFISC = @P_CDREGRAFISC
         AND DADOSFISCNCM.CDIMPOSTO = IMPOSTO.CDIMPOSTO;
   OPEN C_DADOSFISCNCM;
   FETCH NEXT FROM C_DADOSFISCNCM INTO @V_DADOSFISCNCM_CDIMPOSTONFE,
                                       @V_DADOSFISCNCM_CDIMPOSTO,
                                       @V_DADOSFISCNCM_CDSITUTRIB,
                                       @V_DADOSFISCNCM_CDFISCAL,
                                       @V_DADOSFISCNCM_IDUTVLRQTDEIMPO,
                                       @V_DADOSFISCNCM_CDNATUBCPCSTNFE,
                                       @V_DADOSFISCNCM_CDTPCRPICOSTNFE,
                                       @V_DADOSFISCNCM_VRALIQUOTA,
                                       @V_DADOSFISCNCM_CDNATUREC;
   WHILE (@@FETCH_STATUS = 0)
   BEGIN
      IF @V_DADOSFISCNCM_CDSITUTRIB IS NOT NULL BEGIN
         IF @V_DADOSFISCNCM_CDIMPOSTONFE IS NOT NULL BEGIN
            SET @V_COUNT = 0;
            SELECT @V_COUNT = COUNT(1)
              FROM PARAMCST
             WHERE CDIMPOSTO  = @V_DADOSFISCNCM_CDIMPOSTONFE
               AND CDSITUTRIB = @V_DADOSFISCNCM_CDSITUTRIB;
            IF @V_COUNT = 0 BEGIN
               INSERT INTO @ERRO_REGRAFISCAL_TABLE(CDREGRAFISC, CDIMPOSTO, CDIMPOSTONFE, CDSITUTRIB, IDCADPADRAO, IDERRO)
               VALUES (@P_CDREGRAFISC, @V_DADOSFISCNCM_CDIMPOSTO, @V_DADOSFISCNCM_CDIMPOSTONFE, @V_DADOSFISCNCM_CDSITUTRIB, 'X', 4) /*CST no cadastrado para o imposto.*/
            END;

            SET @V_COUNT = 0;
            SELECT @V_COUNT = COUNT(1)
              FROM PARAMCST
             WHERE CDIMPOSTO  = @V_DADOSFISCNCM_CDIMPOSTONFE
               AND CDSITUTRIB = @V_DADOSFISCNCM_CDSITUTRIB
               AND ((IDUTICDFISCAL1 = 'S' AND @V_DADOSFISCNCM_CDFISCAL = '1') OR
                    (IDUTICDFISCAL2 = 'S' AND @V_DADOSFISCNCM_CDFISCAL = '2') OR
                    (IDUTICDFISCAL3 = 'S' AND @V_DADOSFISCNCM_CDFISCAL = '3'));
            IF @V_COUNT = 0 BEGIN
               INSERT INTO @ERRO_REGRAFISCAL_TABLE(CDREGRAFISC, CDIMPOSTO, CDIMPOSTONFE, CDSITUTRIB, CDFISCAL, IDCADPADRAO, IDERRO)
               VALUES (@P_CDREGRAFISC, @V_DADOSFISCNCM_CDIMPOSTO, @V_DADOSFISCNCM_CDIMPOSTONFE, @V_DADOSFISCNCM_CDSITUTRIB, @V_DADOSFISCNCM_CDFISCAL, 'X', 5) /*Cdigo Fiscal invlido para o respectivo CST e imposto*/
            END;

            IF @V_DADOSFISCNCM_IDUTVLRQTDEIMPO = 'S' BEGIN
               SET @V_COUNT = 0;
               SELECT @V_COUNT = COUNT(1)
                 FROM PARAMCST
                WHERE CDIMPOSTO      = @V_DADOSFISCNCM_CDIMPOSTONFE
                  AND CDSITUTRIB     = @V_DADOSFISCNCM_CDSITUTRIB;
               IF @V_COUNT = 0 BEGIN
                  INSERT INTO @ERRO_REGRAFISCAL_TABLE(CDREGRAFISC, CDIMPOSTO, CDIMPOSTONFE, CDSITUTRIB, IDCADPADRAO, IDERRO)
                  VALUES (@P_CDREGRAFISC, @V_DADOSFISCNCM_CDIMPOSTO, @V_DADOSFISCNCM_CDIMPOSTONFE, @V_DADOSFISCNCM_CDSITUTRIB, 'X', 6) /*CST invlido para imposto cujo valor de alquota  definido por quantidade.*/
               END;
            END;

            IF @V_DADOSFISCNCM_CDNATUBCPCSTNFE IS NULL OR
               @V_DADOSFISCNCM_CDTPCRPICOSTNFE IS NULL BEGIN
               SET @V_COUNT = 0;
               SELECT @V_COUNT = COUNT(1)
                 FROM PARAMCST
                WHERE CDIMPOSTO       = @V_DADOSFISCNCM_CDIMPOSTONFE
                  AND CDSITUTRIB      = @V_DADOSFISCNCM_CDSITUTRIB
                  AND IDUTITIPCREDITO = 'N';
               IF @V_COUNT = 0 BEGIN
                  INSERT INTO @ERRO_REGRAFISCAL_TABLE(CDREGRAFISC, CDIMPOSTO, CDIMPOSTONFE, CDSITUTRIB, IDCADPADRAO, IDERRO)
                  VALUES (@P_CDREGRAFISC, @V_DADOSFISCNCM_CDIMPOSTO, @V_DADOSFISCNCM_CDIMPOSTONFE, @V_DADOSFISCNCM_CDSITUTRIB, 'X', 7) /*Tipo de Credito e natureza da base de clculo obrigatorios para o respectivo imposto e CST*/
               END;
            END;

            
         END;
      END;

      IF (@V_DADOSFISCNCM_CDIMPOSTONFE = '50') OR (@V_DADOSFISCNCM_CDIMPOSTONFE = '60') BEGIN
         IF (@V_DADOSFISCNCM_CDSITUTRIB <> '05') AND (@V_DADOSFISCNCM_CDSITUTRIB <> '49') AND (@V_DADOSFISCNCM_CDSITUTRIB <> '99') BEGIN
            SET @V_COUNT = 0;
            SELECT @V_COUNT = COUNT(1)
              FROM ALIQUOTACSTNFE
             WHERE CDIMPOSTO = @V_DADOSFISCNCM_CDIMPOSTONFE
               AND CDSITUTRIBNFE = @V_DADOSFISCNCM_CDSITUTRIB
               AND VRALIQUOTA = CASE @V_DADOSFISCNCM_CDFISCAL WHEN '1' THEN @V_DADOSFISCNCM_VRALIQUOTA ELSE 0 END;
            IF @V_COUNT = 0 BEGIN
               INSERT INTO @ERRO_REGRAFISCAL_TABLE(CDREGRAFISC, CDIMPOSTO, CDIMPOSTONFE, CDSITUTRIB, IDCADPADRAO, IDERRO)
               VALUES (@P_CDREGRAFISC, @V_DADOSFISCNCM_CDIMPOSTO, @V_DADOSFISCNCM_CDIMPOSTONFE, @V_DADOSFISCNCM_CDSITUTRIB, 'X', 8) /*Valor de aliquota invalida para o respectivo imposto e CST*/
            END;
         END;

      END;
      FETCH NEXT FROM C_DADOSFISCNCM INTO @V_DADOSFISCNCM_CDIMPOSTONFE,
                                          @V_DADOSFISCNCM_CDIMPOSTO,
                                          @V_DADOSFISCNCM_CDSITUTRIB,
                                          @V_DADOSFISCNCM_CDFISCAL,
                                          @V_DADOSFISCNCM_IDUTVLRQTDEIMPO,
                                          @V_DADOSFISCNCM_CDNATUBCPCSTNFE,
                                          @V_DADOSFISCNCM_CDTPCRPICOSTNFE,
                                          @V_DADOSFISCNCM_VRALIQUOTA,
                                          @V_DADOSFISCNCM_CDNATUREC;

   END;
   CLOSE C_DADOSFISCNCM;
   DEALLOCATE C_DADOSFISCNCM;

   DECLARE @V_VINCULOFISREGRA_CDEMPRESA       VARCHAR(2);
   DECLARE @V_VINCULOFISREGRA_IDENTRSAIDOP    VARCHAR(1);
   DECLARE @V_VINCULOFISREGRA_CDTIPOOPER      VARCHAR(2);
   DECLARE @V_VINCULOFISREGRA_CDINSCESTA      VARCHAR(16);
   DECLARE @V_VINCULOFISREGRA_CDGRUPOFISC     VARCHAR(3);
   DECLARE @V_VINCULOFISREGRA_NRORDPRIORIDADE INTEGER;
   DECLARE @V_VINCULOFISREGRA_DTVALVINCFISC   DATETIME;
   DECLARE @V_IDUTGRUPOFISCAL                 VARCHAR(1);

   DECLARE C_VINCULOFISREGRA CURSOR FOR
      SELECT CDEMPRESA, IDENTRSAIDOP, CDTIPOOPER, CDINSCESTA, CDGRUPOFISC, NRORDPRIORIDADE, DTVALVINCFISC
        FROM VINCULOFISREGRA
       WHERE VINCULOFISREGRA.CDREGRAFISC = @P_CDREGRAFISC;
   OPEN C_VINCULOFISREGRA;
   FETCH NEXT FROM C_VINCULOFISREGRA INTO @V_VINCULOFISREGRA_CDEMPRESA,
                                          @V_VINCULOFISREGRA_IDENTRSAIDOP,
                                          @V_VINCULOFISREGRA_CDTIPOOPER,
                                          @V_VINCULOFISREGRA_CDINSCESTA,
                                          @V_VINCULOFISREGRA_CDGRUPOFISC,
                                          @V_VINCULOFISREGRA_NRORDPRIORIDADE,
                                          @V_VINCULOFISREGRA_DTVALVINCFISC;
   WHILE (@@FETCH_STATUS = 0)
   BEGIN
      SET @V_COUNT = 0;

      SELECT @V_IDUTGRUPOFISCAL = MAX(REGRAFISCAL.IDUTGRUPOFISCAL)
        FROM REGRAFISCAL
        WHERE REGRAFISCAL.CDREGRAFISC = @P_CDREGRAFISC;

      IF @V_IDUTGRUPOFISCAL = 'S' BEGIN

         SELECT @V_COUNT = COUNT(1)
           FROM VINCULOFISREGRA, REGRAFISCAL
          WHERE VINCULOFISREGRA.CDREGRAFISC     <> @P_CDREGRAFISC
            AND VINCULOFISREGRA.CDEMPRESA       =  @V_VINCULOFISREGRA_CDEMPRESA
            AND (ISNULL(VINCULOFISREGRA.IDENTRSAIDOP, 'T') = ISNULL(@V_VINCULOFISREGRA_IDENTRSAIDOP, 'T'))
            AND (ISNULL(VINCULOFISREGRA.CDTIPOOPER  , 'T') = ISNULL(@V_VINCULOFISREGRA_CDTIPOOPER, 'T'))
            AND (ISNULL(VINCULOFISREGRA.CDINSCESTA  , 'T') = ISNULL(@V_VINCULOFISREGRA_CDINSCESTA, 'T'))
            AND VINCULOFISREGRA.CDREGRAFISC     = REGRAFISCAL.CDREGRAFISC
            AND REGRAFISCAL.IDATIVREGRAFISC     = 'S'
            AND (EXISTS (SELECT 1
                          FROM GRUPOFISCREGRA A, GRUPOFISCREGRA B
                         WHERE A.CDREGRAFISC = VINCULOFISREGRA.CDREGRAFISC
                           AND B.CDREGRAFISC = @P_CDREGRAFISC
                           AND A.CDGRUPOFISC = B.CDGRUPOFISC))
            AND EXISTS (SELECT 1
                          FROM IMPREGRAFISCAL A, IMPREGRAFISCAL B
                         WHERE A.CDREGRAFISC = VINCULOFISREGRA.CDREGRAFISC
                           AND B.CDREGRAFISC = @P_CDREGRAFISC
                           AND A.CDIMPOSTO   = B.CDIMPOSTO);
      END
      ELSE BEGIN
         SELECT @V_COUNT = COUNT(1)
           FROM VINCULOFISREGRA, REGRAFISCAL
          WHERE VINCULOFISREGRA.CDREGRAFISC     <> @P_CDREGRAFISC
            AND VINCULOFISREGRA.CDEMPRESA       =  @V_VINCULOFISREGRA_CDEMPRESA
            AND (ISNULL(VINCULOFISREGRA.IDENTRSAIDOP, 'T') = ISNULL(@V_VINCULOFISREGRA_IDENTRSAIDOP, 'T'))
            AND (ISNULL(VINCULOFISREGRA.CDTIPOOPER  , 'T') = ISNULL(@V_VINCULOFISREGRA_CDTIPOOPER, 'T'))
            AND (ISNULL(VINCULOFISREGRA.CDINSCESTA  , 'T') = ISNULL(@V_VINCULOFISREGRA_CDINSCESTA, 'T'))
            AND VINCULOFISREGRA.CDREGRAFISC     = REGRAFISCAL.CDREGRAFISC
            AND REGRAFISCAL.IDATIVREGRAFISC     = 'S'
            AND REGRAFISCAL.IDUTGRUPOFISCAL <> 'S'
            AND EXISTS (SELECT 1
                          FROM IMPREGRAFISCAL A, IMPREGRAFISCAL B
                         WHERE A.CDREGRAFISC = VINCULOFISREGRA.CDREGRAFISC
                           AND B.CDREGRAFISC = @P_CDREGRAFISC
                           AND A.CDIMPOSTO   = B.CDIMPOSTO);
      END;
      IF @V_COUNT > 0 BEGIN
         INSERT INTO @ERRO_REGRAFISCAL_TABLE(CDREGRAFISC, IDERRO)
         VALUES (@P_CDREGRAFISC, 9) /*Vinculo ja cadastrado para outra regra fiscal ativa*/
      END;
      FETCH NEXT FROM C_VINCULOFISREGRA INTO @V_VINCULOFISREGRA_CDEMPRESA,
                                             @V_VINCULOFISREGRA_IDENTRSAIDOP,
                                             @V_VINCULOFISREGRA_CDTIPOOPER,
                                             @V_VINCULOFISREGRA_CDINSCESTA,
                                             @V_VINCULOFISREGRA_CDGRUPOFISC,
                                             @V_VINCULOFISREGRA_NRORDPRIORIDADE,
                                             @V_VINCULOFISREGRA_DTVALVINCFISC;

   END;
   CLOSE C_VINCULOFISREGRA;
   DEALLOCATE C_VINCULOFISREGRA;
   SET @V_COUNT = 0;
   SELECT @V_COUNT = COUNT(1)
     FROM REGRAFISCAL
    WHERE REGRAFISCAL.CDREGRAFISC = @P_CDREGRAFISC
      AND REGRAFISCAL.IDUTGRUPOFISCAL = 'N'
      AND EXISTS (SELECT 1
                    FROM GRUPOFISCREGRA
                   WHERE GRUPOFISCREGRA.CDREGRAFISC = @P_CDREGRAFISC);
   IF @V_COUNT > 0 BEGIN
      INSERT INTO @ERRO_REGRAFISCAL_TABLE(CDREGRAFISC, IDERRO)
      VALUES (@P_CDREGRAFISC, 11) /*Regra nao utiliza grupo fiscal porem, existem grupos fiscais parametrizados para a mesma*/
   END;

   SET @V_COUNT = 0;
   SELECT @V_COUNT = COUNT(1)
     FROM REGRAFISCAL
    WHERE REGRAFISCAL.CDREGRAFISC = @P_CDREGRAFISC
      AND REGRAFISCAL.IDUTGRUPOFISCAL = 'S'
      AND NOT EXISTS (SELECT 1
                        FROM GRUPOFISCREGRA
                       WHERE GRUPOFISCREGRA.CDREGRAFISC = @P_CDREGRAFISC);
   IF @V_COUNT > 0 BEGIN
      INSERT INTO @ERRO_REGRAFISCAL_TABLE(CDREGRAFISC, IDERRO)
      VALUES (@P_CDREGRAFISC, 12) /*Regra utiliza grupo fiscal porem, nao existem grupos fiscais parametrizados para a mesma*/
   END;
   SET @V_COUNT = 0;
   SELECT @V_COUNT = COUNT(1)
     FROM IMPREGRAFISCAL
    WHERE IMPREGRAFISCAL.CDREGRAFISC = @P_CDREGRAFISC
      AND CDIMPOSTO NOT IN (SELECT IMPREGRAFISCAL.CDIMPOSTO
                              FROM IMPREGRAFISCAL
                             WHERE IMPREGRAFISCAL.CDREGRAFISC = @P_CDREGRAFISC
                               AND NOT EXISTS (SELECT 1
                                                 FROM DADOSFISCREGRA
                                                WHERE DADOSFISCREGRA.CDREGRAFISC = @P_CDREGRAFISC
                                                  AND DADOSFISCREGRA.CDIMPOSTO = IMPREGRAFISCAL.CDIMPOSTO)
                               AND NOT EXISTS (SELECT 1
                                                 FROM DADOSFISCNCM
                                                WHERE DADOSFISCNCM.CDREGRAFISC = @P_CDREGRAFISC
                                                  AND DADOSFISCNCM.CDIMPOSTO = IMPREGRAFISCAL.CDIMPOSTO)
                               AND NOT EXISTS (SELECT 1
                                                 FROM DADOSFISCPROD
                                                WHERE DADOSFISCPROD.CDREGRAFISC = @P_CDREGRAFISC
                                                  AND DADOSFISCPROD.CDIMPOSTO = IMPREGRAFISCAL.CDIMPOSTO));


   IF (@V_COUNT = 0) BEGIN
      DECLARE C_IMPOSTO_OBRIGATORIO CURSOR FOR
         SELECT IMPREGRAFISCAL.CDIMPOSTO, IMPOSTO.CDIMPOSTONFE
            FROM IMPREGRAFISCAL, IMPOSTO
           WHERE IMPREGRAFISCAL.CDREGRAFISC = @P_CDREGRAFISC
             AND IMPREGRAFISCAL.CDIMPOSTO   = IMPOSTO.CDIMPOSTO
             AND NOT EXISTS (SELECT 1
                               FROM DADOSFISCREGRA
                              WHERE DADOSFISCREGRA.CDREGRAFISC = @P_CDREGRAFISC
                                AND DADOSFISCREGRA.CDIMPOSTO = IMPREGRAFISCAL.CDIMPOSTO)
             AND NOT EXISTS (SELECT 1
                               FROM DADOSFISCNCM
                              WHERE DADOSFISCNCM.CDREGRAFISC = @P_CDREGRAFISC
                                AND DADOSFISCNCM.CDIMPOSTO = IMPREGRAFISCAL.CDIMPOSTO)
             AND NOT EXISTS (SELECT 1
                               FROM DADOSFISCPROD
                              WHERE DADOSFISCPROD.CDREGRAFISC = @P_CDREGRAFISC
                                AND DADOSFISCPROD.CDIMPOSTO = IMPREGRAFISCAL.CDIMPOSTO)
          ORDER BY IMPREGRAFISCAL.CDIMPOSTO;
      OPEN C_IMPOSTO_OBRIGATORIO;
      FETCH NEXT FROM C_IMPOSTO_OBRIGATORIO INTO @V_IMPOSTO_OBRIGATORIO_CDIMPOSTO,
                                                 @V_IMPOSTO_OBRIGATORIO_CDIMPOSTONFE;
      WHILE (@@FETCH_STATUS = 0)
      BEGIN
         INSERT INTO @ERRO_REGRAFISCAL_TABLE(CDREGRAFISC, CDIMPOSTO, CDIMPOSTONFE, IDERRO)
                                     VALUES (@P_CDREGRAFISC, @V_IMPOSTO_OBRIGATORIO_CDIMPOSTO, @V_IMPOSTO_OBRIGATORIO_CDIMPOSTONFE, 13) /*Imposto sem dados fiscais*/
         FETCH NEXT FROM C_IMPOSTO_OBRIGATORIO INTO @V_IMPOSTO_OBRIGATORIO_CDIMPOSTO,
                                                    @V_IMPOSTO_OBRIGATORIO_CDIMPOSTONFE;
      END;
      CLOSE C_IMPOSTO_OBRIGATORIO;
      DEALLOCATE C_IMPOSTO_OBRIGATORIO;

      SET @V_COUNT = 0;
      SELECT @V_COUNT = COUNT(1)
        FROM IMPREGRAFISCAL
       WHERE IMPREGRAFISCAL.CDREGRAFISC = @P_CDREGRAFISC;
      IF (@V_COUNT = 0) BEGIN
         INSERT INTO @ERRO_REGRAFISCAL_TABLE(CDREGRAFISC, IDERRO)
                                     VALUES (@P_CDREGRAFISC, 14) /*Regra sem impostos*/
      END;
   END;
   DECLARE C_IMPOSTO_RANGE CURSOR FOR
      SELECT IMPREGRAFISCAL.CDIMPOSTO
        FROM IMPREGRAFISCAL, IMPOSTO
       WHERE IMPREGRAFISCAL.CDREGRAFISC = @P_CDREGRAFISC
         AND IMPREGRAFISCAL.CDIMPOSTO   = IMPOSTO.CDIMPOSTO
         AND IMPOSTO.IDUTRANGEMB        = 'N'
         AND EXISTS (SELECT 1
                       FROM DADOSFISCNCM
                      WHERE DADOSFISCNCM.CDREGRAFISC = @P_CDREGRAFISC
                        AND DADOSFISCNCM.CDIMPOSTO   = IMPREGRAFISCAL.CDIMPOSTO
                        AND DADOSFISCNCM.VRRANGINI IS NOT NULL)
       ORDER BY IMPREGRAFISCAL.CDIMPOSTO
   OPEN C_IMPOSTO_RANGE;
   FETCH NEXT FROM C_IMPOSTO_RANGE INTO @V_IMPOSTO_RANGE;
   WHILE (@@FETCH_STATUS = 0)
   BEGIN
      INSERT INTO @ERRO_REGRAFISCAL_TABLE(CDREGRAFISC, CDIMPOSTO, IDERRO)
                                  VALUES (@P_CDREGRAFISC, @V_IMPOSTO_RANGE, 15) /*Imposto cadastrado com range mas com o parmetro de utilizar range desmarcado*/
      FETCH NEXT FROM C_IMPOSTO_RANGE INTO @V_IMPOSTO_RANGE;
   END;
   CLOSE C_IMPOSTO_RANGE;
   DEALLOCATE C_IMPOSTO_RANGE;

   RETURN;
END;
GO

-- VERSAO --
EXEC ATUVEROBJ 'CONSULTA_ERRO_REGRAFISCAL','5.60.000';
GO
