var RequestTotalizerDataSourceEngine = (function(_super){
  __extends(_RequestTotalizerDataSourceEngine, _super);

  function _RequestTotalizerDataSourceEngine (requestEngine, requestFactory, MethodBuilder, ScreenService, ZHPromise, ZhUtil, dataSourceHolder, templateManager) {
    var _ref = RequestTotalizerDataSourceEngine.__super__.constructor.apply(this, arguments);

    function showMessages(messages) {
      if (messages) {
        ScreenService.showMessage(messages[0].message, messages[0].type, undefined, messages[0].variables);
      }
    }
    function showNotifications(notifications) {
      if (notifications) {
        notifications.forEach(function(notification) {
          ScreenService.notificationMessage(notification.message, notification.type, undefined, notification.variables);
        });
      }
    }
    function buildMethods(methods) {
      for (var i in methods) {
        if (methods.hasOwnProperty(i)) {
          var method = methods[i];
          var params = item.map(function(item) {
            return '"' + item + '"';
          }).join(',');
          var code = method.name + "(" + params + ");";
          MethodBuilder.build(code, {
            event: {
              code: code
            }
          })();
        }
      }
    }

    function _getDataSourceSetResult(dataSourceName, callBack, parent) {
      return function(data) {
      	var dataset = data.dataset;
        if (dataset && Util.isFunction(callBack)) {
          if(dataset.totals && parent){
          	parent.dataSource.totals = dataset.totals;
          	delete dataset.totals;
          }
          var keys = Object.keys(dataset);
          if (keys.length === 1) {
            var datasetNameFormated = keys[0];
            if (datasetNameFormated.indexOf('/') !== 0) {
              datasetNameFormated = '/' + datasetNameFormated;
            }
            callBack(data.dataset[keys[0]], datasetNameFormated);
          } else {
            callBack(data.dataset, keys);
          }
        }

        showMessages(data.messages);
        showNotifications(data.notifications);
        buildMethods(data.method);
      };
    }

    this.getDataSource = function(name, callBack, filter, page, itemsPerPage, errorCallBack, retryCount, timeout, retryCallback, disableLoader, parent) {
      var params = this.buildGetDataSourceParams(callBack, filter, page, itemsPerPage, errorCallBack, retryCount, timeout, retryCallback);
      var processError = this._getDataSourceProcessError(params.errorCallBack);
      var setResult = _getDataSourceSetResult(name, callBack, parent);
      var request = requestFactory.factory({
        requestType: "filterData",
        filter: params.localFilter,
        page: params.page,
        itemsPerPage: params.itemsPerPage,
        serviceName: name,
        disableLoader: disableLoader,
        callBack: setResult,
        errorCallBack: processError,
        timeout: params.timeout,
        retryCount: params.retryCount,
        retryCallback: params.retryCallback
      }, name, setResult);
      var getRequestParams = request.getRequestParams;

      request.requestType = "Empty";
      request.getRequestParams = function(){
        var requestParams = getRequestParams();
        var expressions = {};
        parent.fields.filter(function(field) {
            return !!field.expression && !field.grouped;
        }).map(function(field){
            expressions[field.name] = field.expression;
        });

        requestParams.expressions = {
          groupColumns: parent.groups ? parent.groups.map(function(group){
            return group.name;
          }) : [],
          expressions: expressions
        };
        return requestParams;
      };

      dataSourceHolder.getDataSource(name);
      return requestEngine.doRequest(request);
    };

    return _ref;
  }

  return _RequestTotalizerDataSourceEngine;
})(RequestDataSourceEngine);